You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by si...@apache.org on 2011/06/15 01:00:38 UTC

svn commit: r1135839 - /commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/Path.java

Author: simonetripodi
Date: Tue Jun 14 23:00:38 2011
New Revision: 1135839

URL: http://svn.apache.org/viewvc?rev=1135839&view=rev
Log:
start/end renamed to source/target, since such terms are used more often in literature 

Modified:
    commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/Path.java

Modified: commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/Path.java
URL: http://svn.apache.org/viewvc/commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/Path.java?rev=1135839&r1=1135838&r2=1135839&view=diff
==============================================================================
--- commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/Path.java (original)
+++ commons/sandbox/graph/trunk/src/main/java/org/apache/commons/graph/Path.java Tue Jun 14 23:00:38 2011
@@ -32,14 +32,14 @@ public interface Path<V extends Vertex, 
 {
 
     /**
      * Returns the start of the path.
      */
-    V getStart();
+    V getSource();
 
     /**
      * Returns the end of the path.
      */
-    V getEnd();
+    V getTarget();
 
     /**
      * getVertices() - This returns a list of Vertices, in order as they go from
@@ -32,14 +32,14 @@ public interface Path<V extends Vertex, 
 
     /**
-     * Returns the start of the path.
+     * Returns the source of the path.
      */
@@ -32,14 +32,14 @@ public interface Path<V extends Vertex, 
 
     /**
-     * Returns the end of the path.
+     * Returns the target of the path.
      */